@@ -1,11 +1,12 @@
 #' Read from the file (JSON/INI/YAML/TOML be supported), retreiving all values as a list.
 #'
 #' @param file File name of configuration file to read from. Defaults to the value of
-#' the ‘R_CONFIGFILE_ACTIVE’ environment variable ('config.cfg' if the
+#' the 'R_CONFIGFILE_ACTIVE' environment variable ('config.cfg' if the
 #' variable does not exist and JSON/INI/YAML/TOML format only)
-#' @param extra.list A list that can replace the configuration file "{{debug}}" by list(debug = "TRUE"), 
-#' and {{debug}} will be setted to "TRUE"
-#' @param other.config Path of another configuration file that can replace the configuration file "{{key:value}}" 
+#' @param extra.list A list that can replace the configuration file '{{debug}}' by list(debug = 'TRUE'), 
+#' and {{debug}} will be setted to 'TRUE'
+#' @param other.config Path of another configuration file that can replace the configuration file '{{key:value}}' 
+#' @param rcmd.parse Logical wheather parse '@>@str_replace('abc', 'b', 'c')@<@' that existed in config to 'acc'
 #' @param ... Arguments for \code{\link{get.config.type}}, 
 #' \code{\link[jsonlite]{fromJSON}}, \code{\link[ini]{read.ini}},
 #' \code{\link[yaml]{yaml.load_file}}, \code{\link[RcppTOML]{parseTOML}}, 
@@ -24,10 +25,11 @@
 #' @examples
 #' config.json <- system.file('extdata', 'config.json', package='configr')
 #' config <- read.config(file=config.json)
-#' config.extra.parsed.1 <- read.config(config.json, list(debug = "TRUE"))
+#' config.extra.parsed.1 <- read.config(config.json, list(debug = 'TRUE'))
 #' other.config <- system.file('extdata', 'config.other.yaml', package='configr')
-#' config.extra.parsed.2 <- read.config(config.json, list(debug = "TRUE"), other.config)
-read.config <- function(file = Sys.getenv("R_CONFIGFILE_ACTIVE", "config.cfg"), extra.list = list(), other.config = "", ...) {
+#' config.extra.parsed.2 <- read.config(config.json, list(debug = 'TRUE'), other.config)
+read.config <- function(file = Sys.getenv("R_CONFIGFILE_ACTIVE", "config.cfg"), extra.list = list(), 
+  other.config = "", rcmd.parse = FALSE, ...) {
   status <- check.file.parameter(file)
   if (status == FALSE) {
     return(FALSE)
@@ -36,7 +38,8 @@ read.config <- function(file = Sys.getenv("R_CONFIGFILE_ACTIVE", "config.cfg"),
   if (!is.character(file.type)) {
     return(FALSE)
   }
-  config.list <- get.config.list(file = file, file.type = file.type, extra.list = extra.list, other.config = other.config, ...)
+  config.list <- get.config.list(file = file, file.type = file.type, extra.list = extra.list, 
+    other.config = other.config, rcmd.parse = rcmd.parse, ...)
   return(config.list)
 }
 
@@ -45,7 +48,7 @@ read.config <- function(file = Sys.getenv("R_CONFIGFILE_ACTIVE", "config.cfg"),
 #' have 'config', 'configtype', 'file' 'property.
 #'
 #' @param file File name of configuration file to read from. Defaults to the value of
-#' the ‘R_CONFIGFILE_ACTIVE’ environment variable ('config.cfg' if the
+#' the 'R_CONFIGFILE_ACTIVE' environment variable ('config.cfg' if the
 #' variable does not exist and JSON/INI/YAML/TOML format only) 
 #' @param value Name of value (NULL to read all values)
 #' @param config Name of configuration to read from. Defaults to the value of 
@@ -60,9 +63,9 @@ read.config <- function(file = Sys.getenv("R_CONFIGFILE_ACTIVE", "config.cfg"),
 #' @examples
 #' config.json <- system.file('extdata', 'config.json', package='configr')
 #' config <- eval.config(file=config.json)
-#' config.extra.parsed.1 <- eval.config(file = config.json, extra.list = list(debug = "TRUE"))
+#' config.extra.parsed.1 <- eval.config(file = config.json, extra.list = list(debug = 'TRUE'))
 #' other.config <- system.file('extdata', 'config.other.yaml', package='configr')
-#' config.extra.parsed.2 <- eval.config(file = config.json, extra.list = list(debug = "TRUE"), 
+#' config.extra.parsed.2 <- eval.config(file = config.json, extra.list = list(debug = 'TRUE'), 
 #' other.config = other.config)
 #' @export
 eval.config <- function(value = NULL, config = Sys.getenv("R_CONFIG_ACTIVE", "default"), 
@@ -84,7 +87,7 @@ eval.config <- function(value = NULL, config = Sys.getenv("R_CONFIG_ACTIVE", "de
 #' 
 #'
 #' @param file File name of configuration file to read from. Defaults to the value of
-#' the ‘R_CONFIGFILE_ACTIVE’ environment variable ('config.cfg' if the
+#' the 'R_CONFIGFILE_ACTIVE' environment variable ('config.cfg' if the
 #' variable does not exist and JSON/INI/YAML/TOML format only)
 #' @param ... Arguments for \code{\link{read.config}} 
 #' @seealso
